# Twelve colors

```graphviz
digraph Twelve_colors {
    label = "Twelve colors. Neato layout"
    labelloc = "b"
    layout = neato
    fontname = Arial
    node [
        shape = circle
        width = 1.5
        color="#00000088"
        style = filled
        fontname="Helvetica,Arial,sans-serif"
    ]
    edge [len = 2 penwidth = 1.5 arrowhead=open]
    start = regular
    normalize = 0
    green -> {white yellow cyan yellowgreen springgreen} [color = green]
    green [fillcolor = green fontcolor = white]
    white [fillcolor = white]
    blue [fillcolor = blue fontcolor = white]
    red [fillcolor = red fontcolor = white]
    red -> {white yellow magenta orange deeppink } [color = red]
    yellow [fillcolor = yellow]
    yellow -> {orange yellowgreen} [color = yellow]
    blue -> {white cyan magenta deepskyblue purple} [color = blue]
    cyan [fillcolor = cyan]
    magenta [fillcolor = magenta fontcolor = white]
    deepskyblue [fillcolor = deepskyblue]
    cyan -> {springgreen deepskyblue} [color  = cyan]
    orange [fillcolor = orange]
    yellowgreen [fillcolor = yellowgreen]
    deeppink [fillcolor = deeppink fontcolor = white]
    magenta -> {deeppink purple} [color = magenta]
    purple [fillcolor = purple fontcolor = white]
    springgreen [fillcolor = springgreen]
    // © 2022 Costa Shulyupin, licensed under EPL
}
```
